@@ -169,15 +169,14 @@ class DistroRepository(Linux):
         return [x for x in reduce(lambda x, y: x + y, allFiles, []) if distfilter(x)]
 
     @staticmethod
-    def extcomparator(self, *exts):
+    def extcomparator(ext1, ext2):
         """Compare extensions"""
         mapExts = {'iso': 0,
                    'flash': -1,
                    'isodir': -2,
                    'partdir': -3,
                    'dir': -4}
-        
-        return cmp(mapExts.get(exts[0], -4), mapExts.get(exts[1], -4))
+        return cmp(mapExts.get(ext1, -4), mapExts.get(ext2, -4))
 
 
     @staticmethod
